{% extends 'base.html' %}
{% block title %}404: Not Found{% endblock %}

{% block content %}
<div class="panel panel-danger">
  <div class="panel-heading">
    {{ error.__class__.__name__ }}
  </div>
  <div class="panel-body">
    {{ error }}
  </div>
</div>
{% endblock %}
